@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -35,7 +35,18 @@ extern "C" {
 #endif
 
 /** \page H5LT_UG HDF5 High Level Lite
+ *
+ * Navigate back: \ref index "Main" / \ref UG
+ * <hr>
+ *
+ * \section sec_hl_lite_api HDF5 Lite APIs
+ *
  * @todo Under Construction
+ *
+ * Previous Chapter \ref sec_hl_images - Next Chapter \ref sec_hl_table_api
+ *
+ * <hr>
+ * Navigate back: \ref index "Main" / \ref UG
  */
 
 /**\defgroup H5LT HDF5 Lite APIs (H5LT,H5LD)
@@ -187,7 +198,7 @@ extern "C" {
  *                with more than three dimensions.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                  hid_t type_id, const void *buffer);
 
 /**
@@ -211,7 +222,7 @@ H5_HLDLL herr_t H5LTmake_dataset(hid_t loc_id, const char *dset_name, int rank,
  *          The dataset's datatype will be \e character, #H5T_NATIVE_CHAR.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_char(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset_char(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                       const char *buffer);
 
 /**
@@ -236,7 +247,7 @@ H5_HLDLL herr_t H5LTmake_dataset_char(hid_t loc_id, const char *dset_name, int r
  *          #H5T_NATIVE_SHORT.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_short(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset_short(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                        const short *buffer);
 
 /**
@@ -264,7 +275,7 @@ H5_HLDLL herr_t H5LTmake_dataset_short(hid_t loc_id, const char *dset_name, int
  *          arrays with more than three dimensions.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_int(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset_int(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                      const int *buffer);
 
 /**
@@ -289,7 +300,7 @@ H5_HLDLL herr_t H5LTmake_dataset_int(hid_t loc_id, const char *dset_name, int ra
  *          #H5T_NATIVE_LONG.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_long(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset_long(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                       const long *buffer);
 
 /**
@@ -317,7 +328,7 @@ H5_HLDLL herr_t H5LTmake_dataset_long(hid_t loc_id, const char *dset_name, int r
  *                arrays with more than three dimensions.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_float(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset_float(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                        const float *buffer);
 
 /**
@@ -345,7 +356,7 @@ H5_HLDLL herr_t H5LTmake_dataset_float(hid_t loc_id, const char *dset_name, int
  *                arrays with more than three dimensions.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_double(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
+H5HL_DLL herr_t H5LTmake_dataset_double(hid_t loc_id, const char *dset_name, int rank, const hsize_t *dims,
                                         const double *buffer);
 
 /**
@@ -367,7 +378,7 @@ H5_HLDLL herr_t H5LTmake_dataset_double(hid_t loc_id, const char *dset_name, int
  *          The dataset's datatype will be <em>C string</em>, #H5T_C_S1.
  *
  */
-H5_HLDLL herr_t H5LTmake_dataset_string(hid_t loc_id, const char *dset_name, const char *buf);
+H5HL_DLL herr_t H5LTmake_dataset_string(hid_t loc_id, const char *dset_name, const char *buf);
 
 /*-------------------------------------------------------------------------
  *
@@ -399,7 +410,7 @@ H5_HLDLL herr_t H5LTmake_dataset_string(hid_t loc_id, const char *dset_name, con
  *                  accommodate arrays with more than three dimensions.
  *
  */
-H5_HLDLL herr_t H5LTread_dataset(hid_t loc_id, const char *dset_name, hid_t type_id, void *buffer);
+H5HL_DLL herr_t H5LTread_dataset(hid_t loc_id, const char *dset_name, hid_t type_id, void *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -418,7 +429,7 @@ H5_HLDLL herr_t H5LTread_dataset(hid_t loc_id, const char *dset_name, hid_t type
  *          The HDF5 datatype is #H5T_NATIVE_CHAR.
  *
  */
-H5_HLDLL herr_t H5LTread_dataset_char(hid_t loc_id, const char *dset_name, char *buffer);
+H5HL_DLL herr_t H5LTread_dataset_char(hid_t loc_id, const char *dset_name, char *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -437,7 +448,7 @@ H5_HLDLL herr_t H5LTread_dataset_char(hid_t loc_id, const char *dset_name, char
  *          The HDF5 datatype is #H5T_NATIVE_SHORT.
  *
  */
-H5_HLDLL herr_t H5LTread_dataset_short(hid_t loc_id, const char *dset_name, short *buffer);
+H5HL_DLL herr_t H5LTread_dataset_short(hid_t loc_id, const char *dset_name, short *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -459,7 +470,7 @@ H5_HLDLL herr_t H5LTread_dataset_short(hid_t loc_id, const char *dset_name, shor
  *                accommodate arrays with more than three dimensions.
  *
  */
-H5_HLDLL herr_t H5LTread_dataset_int(hid_t loc_id, const char *dset_name, int *buffer);
+H5HL_DLL herr_t H5LTread_dataset_int(hid_t loc_id, const char *dset_name, int *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -478,7 +489,7 @@ H5_HLDLL herr_t H5LTread_dataset_int(hid_t loc_id, const char *dset_name, int *b
  *          The HDF5 datatype is #H5T_NATIVE_LONG.
  *
  */
-H5_HLDLL herr_t H5LTread_dataset_long(hid_t loc_id, const char *dset_name, long *buffer);
+H5HL_DLL herr_t H5LTread_dataset_long(hid_t loc_id, const char *dset_name, long *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -499,7 +510,7 @@ H5_HLDLL herr_t H5LTread_dataset_long(hid_t loc_id, const char *dset_name, long
  * \version 1.8.7 Fortran subroutine modified in this release to
  *                accommodate arrays with more than three dimensions.
  */
-H5_HLDLL herr_t H5LTread_dataset_float(hid_t loc_id, const char *dset_name, float *buffer);
+H5HL_DLL herr_t H5LTread_dataset_float(hid_t loc_id, const char *dset_name, float *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -520,7 +531,7 @@ H5_HLDLL herr_t H5LTread_dataset_float(hid_t loc_id, const char *dset_name, floa
  * \version 1.8.7 Fortran subroutine modified in this release to
  *                accommodate arrays with more than three dimensions.
  */
-H5_HLDLL herr_t H5LTread_dataset_double(hid_t loc_id, const char *dset_name, double *buffer);
+H5HL_DLL herr_t H5LTread_dataset_double(hid_t loc_id, const char *dset_name, double *buffer);
 
 /**
  *-------------------------------------------------------------------------
@@ -539,7 +550,7 @@ H5_HLDLL herr_t H5LTread_dataset_double(hid_t loc_id, const char *dset_name, dou
  *          The HDF5 datatype is #H5T_C_S1.
  *
  */
-H5_HLDLL herr_t H5LTread_dataset_string(hid_t loc_id, const char *dset_name, char *buf);
+H5HL_DLL herr_t H5LTread_dataset_string(hid_t loc_id, const char *dset_name, char *buf);
 
 /*-------------------------------------------------------------------------
  *
@@ -565,7 +576,7 @@ H5_HLDLL herr_t H5LTread_dataset_string(hid_t loc_id, const char *dset_name, cha
  *          named \p dset_name exists attached to the object \p loc_id.
  *
  */
-H5_HLDLL herr_t H5LTget_dataset_ndims(hid_t loc_id, const char *dset_name, int *rank);
+H5HL_DLL herr_t H5LTget_dataset_ndims(hid_t loc_id, const char *dset_name, int *rank);
 
 /**
  *-------------------------------------------------------------------------
@@ -588,7 +599,7 @@ H5_HLDLL herr_t H5LTget_dataset_ndims(hid_t loc_id, const char *dset_name, int *
  *          named \p dset_name attached to the object \p loc_id.
  *
  */
-H5_HLDLL herr_t H5LTget_dataset_info(hid_t loc_id, const char *dset_name, hsize_t *dims,
+H5HL_DLL herr_t H5LTget_dataset_info(hid_t loc_id, const char *dset_name, hsize_t *dims,
                                      H5T_class_t *type_class, size_t *type_size);
 
 /**
@@ -609,7 +620,7 @@ H5_HLDLL herr_t H5LTget_dataset_info(hid_t loc_id, const char *dset_name, hsize_
  *          specify a dataset that is a member of that group.
  *
  */
-H5_HLDLL herr_t H5LTfind_dataset(hid_t loc_id, const char *name);
+H5HL_DLL herr_t H5LTfind_dataset(hid_t loc_id, const char *name);
 
 /*-------------------------------------------------------------------------
  *
@@ -638,7 +649,7 @@ H5_HLDLL herr_t H5LTfind_dataset(hid_t loc_id, const char *name);
  *          it is overwritten.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_string(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_string(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          const char *attr_data);
 
 /**
@@ -664,7 +675,7 @@ H5_HLDLL herr_t H5LTset_attribute_string(hid_t loc_id, const char *obj_name, con
  *          The HDF5 datatype of the attribute is #H5T_NATIVE_CHAR.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_char(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_char(hid_t loc_id, const char *obj_name, const char *attr_name,
                                        const char *buffer, size_t size);
 
 /**
@@ -690,7 +701,7 @@ H5_HLDLL herr_t H5LTset_attribute_char(hid_t loc_id, const char *obj_name, const
  *          The HDF5 datatype of the attribute is #H5T_NATIVE_UCHAR.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_uchar(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_uchar(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         const unsigned char *buffer, size_t size);
 
 /**
@@ -716,7 +727,7 @@ H5_HLDLL herr_t H5LTset_attribute_uchar(hid_t loc_id, const char *obj_name, cons
  *          The HDF5 datatype of the attribute is #H5T_NATIVE_SHORT.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_short(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_short(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         const short *buffer, size_t size);
 
 /**
@@ -742,7 +753,7 @@ H5_HLDLL herr_t H5LTset_attribute_short(hid_t loc_id, const char *obj_name, cons
  *          The HDF5 datatype of the attribute is #H5T_NATIVE_USHORT.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_ushort(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_ushort(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          const unsigned short *buffer, size_t size);
 
 /**
@@ -769,7 +780,7 @@ H5_HLDLL herr_t H5LTset_attribute_ushort(hid_t loc_id, const char *obj_name, con
  *          is #H5T_NATIVE_INT.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_int(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_int(hid_t loc_id, const char *obj_name, const char *attr_name,
                                       const int *buffer, size_t size);
 
 /**
@@ -795,7 +806,7 @@ H5_HLDLL herr_t H5LTset_attribute_int(hid_t loc_id, const char *obj_name, const
  *          The HDF5 datatype of the attribute is #H5T_NATIVE_UINT.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_uint(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_uint(hid_t loc_id, const char *obj_name, const char *attr_name,
                                        const unsigned int *buffer, size_t size);
 
 /**
@@ -822,7 +833,7 @@ H5_HLDLL herr_t H5LTset_attribute_uint(hid_t loc_id, const char *obj_name, const
  *          is #H5T_NATIVE_LONG.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_long(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_long(hid_t loc_id, const char *obj_name, const char *attr_name,
                                        const long *buffer, size_t size);
 
 /**
@@ -848,7 +859,7 @@ H5_HLDLL herr_t H5LTset_attribute_long(hid_t loc_id, const char *obj_name, const
  *          is #H5T_NATIVE_LLONG.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_long_long(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_long_long(hid_t loc_id, const char *obj_name, const char *attr_name,
                                             const long long *buffer, size_t size);
 
 /**
@@ -875,7 +886,7 @@ H5_HLDLL herr_t H5LTset_attribute_long_long(hid_t loc_id, const char *obj_name,
  *          is #H5T_NATIVE_ULONG.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_ulong(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_ulong(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         const unsigned long *buffer, size_t size);
 
 /**
@@ -901,7 +912,7 @@ H5_HLDLL herr_t H5LTset_attribute_ulong(hid_t loc_id, const char *obj_name, cons
  *          is #H5T_NATIVE_ULLONG.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_ullong(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_ullong(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          const unsigned long long *buffer, size_t size);
 
 /**
@@ -928,7 +939,7 @@ H5_HLDLL herr_t H5LTset_attribute_ullong(hid_t loc_id, const char *obj_name, con
  *          of the attribute is #H5T_NATIVE_FLOAT.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_float(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_float(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         const float *buffer, size_t size);
 
 /**
@@ -955,7 +966,7 @@ H5_HLDLL herr_t H5LTset_attribute_float(hid_t loc_id, const char *obj_name, cons
  *          of the attribute is #H5T_NATIVE_DOUBLE.
  *
  */
-H5_HLDLL herr_t H5LTset_attribute_double(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTset_attribute_double(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          const double *buffer, size_t size);
 
 /*-------------------------------------------------------------------------
@@ -985,7 +996,7 @@ H5_HLDLL herr_t H5LTset_attribute_double(hid_t loc_id, const char *obj_name, con
  *          \p attr_name with the memory type \p mem_type_id.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute(hid_t loc_id, const char *obj_name, const char *attr_name,
                                   hid_t mem_type_id, void *data);
 
 /**
@@ -1014,7 +1025,7 @@ H5_HLDLL herr_t H5LTget_attribute(hid_t loc_id, const char *obj_name, const char
  *                padding; this buffer was previously returned with a C NULL terminator.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_string(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_string(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          char *data);
 
 /**
@@ -1038,7 +1049,7 @@ H5_HLDLL herr_t H5LTget_attribute_string(hid_t loc_id, const char *obj_name, con
  *          is #H5T_NATIVE_CHAR.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_char(hid_t loc_id, const char *obj_name, const char *attr_name, char *data);
+H5HL_DLL herr_t H5LTget_attribute_char(hid_t loc_id, const char *obj_name, const char *attr_name, char *data);
 
 /**
  *-------------------------------------------------------------------------
@@ -1061,7 +1072,7 @@ H5_HLDLL herr_t H5LTget_attribute_char(hid_t loc_id, const char *obj_name, const
  *          attribute is #H5T_NATIVE_UCHAR
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_uchar(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_uchar(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         unsigned char *data);
 
 /**
@@ -1085,7 +1096,7 @@ H5_HLDLL herr_t H5LTget_attribute_uchar(hid_t loc_id, const char *obj_name, cons
  *          attribute is #H5T_NATIVE_SHORT
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_short(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_short(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         short *data);
 
 /**
@@ -1109,7 +1120,7 @@ H5_HLDLL herr_t H5LTget_attribute_short(hid_t loc_id, const char *obj_name, cons
  *          attribute is #H5T_NATIVE_USHORT.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_ushort(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_ushort(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          unsigned short *data);
 
 /**
@@ -1133,7 +1144,7 @@ H5_HLDLL herr_t H5LTget_attribute_ushort(hid_t loc_id, const char *obj_name, con
  *          attribute is #H5T_NATIVE_INT.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_int(hid_t loc_id, const char *obj_name, const char *attr_name, int *data);
+H5HL_DLL herr_t H5LTget_attribute_int(hid_t loc_id, const char *obj_name, const char *attr_name, int *data);
 
 /**
  *-------------------------------------------------------------------------
@@ -1156,7 +1167,7 @@ H5_HLDLL herr_t H5LTget_attribute_int(hid_t loc_id, const char *obj_name, const
  *          attribute is #H5T_NATIVE_INT.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_uint(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_uint(hid_t loc_id, const char *obj_name, const char *attr_name,
                                        unsigned int *data);
 
 /**
@@ -1180,7 +1191,7 @@ H5_HLDLL herr_t H5LTget_attribute_uint(hid_t loc_id, const char *obj_name, const
  *          attribute is #H5T_NATIVE_LONG.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_long(hid_t loc_id, const char *obj_name, const char *attr_name, long *data);
+H5HL_DLL herr_t H5LTget_attribute_long(hid_t loc_id, const char *obj_name, const char *attr_name, long *data);
 
 /**
  *-------------------------------------------------------------------------
@@ -1200,7 +1211,7 @@ H5_HLDLL herr_t H5LTget_attribute_long(hid_t loc_id, const char *obj_name, const
  *          specified by \p loc_id and \p obj_name.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_long_long(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_long_long(hid_t loc_id, const char *obj_name, const char *attr_name,
                                             long long *data);
 
 /**
@@ -1224,7 +1235,7 @@ H5_HLDLL herr_t H5LTget_attribute_long_long(hid_t loc_id, const char *obj_name,
  *          attribute is #H5T_NATIVE_ULONG.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_ulong(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_ulong(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         unsigned long *data);
 
 /**
@@ -1248,7 +1259,7 @@ H5_HLDLL herr_t H5LTget_attribute_ulong(hid_t loc_id, const char *obj_name, cons
  *          attribute is #H5T_NATIVE_ULLONG.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_ullong(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_ullong(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          unsigned long long *data);
 
 /**
@@ -1272,7 +1283,7 @@ H5_HLDLL herr_t H5LTget_attribute_ullong(hid_t loc_id, const char *obj_name, con
  *          attribute is #H5T_NATIVE_FLOAT.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_float(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_float(hid_t loc_id, const char *obj_name, const char *attr_name,
                                         float *data);
 
 /**
@@ -1296,7 +1307,7 @@ H5_HLDLL herr_t H5LTget_attribute_float(hid_t loc_id, const char *obj_name, cons
  *          attribute is #H5T_NATIVE_DOUBLE.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_double(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_double(hid_t loc_id, const char *obj_name, const char *attr_name,
                                          double *data);
 
 /*-------------------------------------------------------------------------
@@ -1326,7 +1337,7 @@ H5_HLDLL herr_t H5LTget_attribute_double(hid_t loc_id, const char *obj_name, con
  *          by the name \p obj_name.
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_ndims(hid_t loc_id, const char *obj_name, const char *attr_name, int *rank);
+H5HL_DLL herr_t H5LTget_attribute_ndims(hid_t loc_id, const char *obj_name, const char *attr_name, int *rank);
 
 /**
  *-------------------------------------------------------------------------
@@ -1355,7 +1366,7 @@ H5_HLDLL herr_t H5LTget_attribute_ndims(hid_t loc_id, const char *obj_name, cons
  * \snippet H5LT_examples.c get_attribute_info
  *
  */
-H5_HLDLL herr_t H5LTget_attribute_info(hid_t loc_id, const char *obj_name, const char *attr_name,
+H5HL_DLL herr_t H5LTget_attribute_info(hid_t loc_id, const char *obj_name, const char *attr_name,
                                        hsize_t *dims, H5T_class_t *type_class, size_t *type_size);
 
 /*-------------------------------------------------------------------------
@@ -1386,8 +1397,7 @@ H5_HLDLL herr_t H5LTget_attribute_info(hid_t loc_id, const char *obj_name, const
  *          \p lang_type definition of HDF5 datatypes.
  *          Currently, only the DDL(#H5LT_DDL) is supported.
  *          The complete DDL definition of HDF5 datatypes can be found in
- *          the specifications chapter of the
- *          <a href="https://\DOXURL/_s_p_e_c.html">
+ *          the \ref SPEC chapter of the
  *          HDF5 User's Guide</a>.
  *
  * \par Example
@@ -1395,7 +1405,7 @@ H5_HLDLL herr_t H5LTget_attribute_info(hid_t loc_id, const char *obj_name, const
  * \snippet H5LT_examples.c enum
  *
  */
-H5_HLDLL hid_t H5LTtext_to_dtype(const char *text, H5LT_lang_t lang_type);
+H5HL_DLL hid_t H5LTtext_to_dtype(const char *text, H5LT_lang_t lang_type);
 
 /**
  *-------------------------------------------------------------------------
@@ -1424,8 +1434,7 @@ H5_HLDLL hid_t H5LTtext_to_dtype(const char *text, H5LT_lang_t lang_type);
  *
  *          Currently only DDL (#H5LT_DDL) is supported for \p lang_type.
  *          The complete DDL definition of HDF5 data types can be found in
- *          the specifications chapter of the
- *          <a href="https://\DOXURL/_s_p_e_c.html">
+ *          the \ref SPEC chapter of the
  *          HDF5 User's Guide</a>.
  *
  * \par Example
@@ -1433,7 +1442,7 @@ H5_HLDLL hid_t H5LTtext_to_dtype(const char *text, H5LT_lang_t lang_type);
  * \snippet H5LT_examples.c enum
  *
  */
-H5_HLDLL herr_t H5LTdtype_to_text(hid_t dtype, char *str, H5LT_lang_t lang_type, size_t *len);
+H5HL_DLL herr_t H5LTdtype_to_text(hid_t dtype, char *str, H5LT_lang_t lang_type, size_t *len);
 
 /*-------------------------------------------------------------------------
  *
@@ -1463,7 +1472,7 @@ H5_HLDLL herr_t H5LTdtype_to_text(hid_t dtype, char *str, H5LT_lang_t lang_type,
  *          to that object.
  *
  */
-H5_HLDLL herr_t H5LTfind_attribute(hid_t loc_id, const char *name);
+H5HL_DLL herr_t H5LTfind_attribute(hid_t loc_id, const char *name);
 
 /**
  *-------------------------------------------------------------------------
@@ -1551,7 +1560,7 @@ H5_HLDLL herr_t H5LTfind_attribute(hid_t loc_id, const char *name);
  *                 See the “Note on Behavior Change” section above.
  *
  */
-H5_HLDLL htri_t H5LTpath_valid(hid_t loc_id, const char *path, hbool_t check_object_valid);
+H5HL_DLL htri_t H5LTpath_valid(hid_t loc_id, const char *path, bool check_object_valid);
 
 /*-------------------------------------------------------------------------
  *
@@ -1625,8 +1634,7 @@ H5_HLDLL htri_t H5LTpath_valid(hid_t loc_id, const char *path, hbool_t check_obj
  * \note      **Recommended Reading:**
  * \note      This function is part of the file image operations feature set.
  *            It is highly recommended to study the guide
- *            <a href="https://\RFCURL/HDF5FileImageOperations.pdf">
- *            HDF5 File Image Operations</a> before using this feature set.\n
+ *            \ref H5FIM_UG before using this feature set.\n
  *            See the “See Also” section below for links to other elements of
  *            HDF5 file image operations.
  *
@@ -1634,7 +1642,7 @@ H5_HLDLL htri_t H5LTpath_valid(hid_t loc_id, const char *path, hbool_t check_obj
  *
  * \since 1.8.9
  */
-H5_HLDLL hid_t H5LTopen_file_image(void *buf_ptr, size_t buf_size, unsigned flags);
+H5HL_DLL hid_t H5LTopen_file_image(void *buf_ptr, size_t buf_size, unsigned flags);
 
 #ifdef __cplusplus
 }
